@@ -387,7 +387,8 @@ def main():
     for command in args.__dict__:
         cv = args.__dict__[command]
         if cv is not None:
-            cv = d.servicetags_from_file(cv) if args.file == True else d.st_array(cv[0])
+            cv = ' '.join(cv) if len(cv) > 1 else cv[0]
+            cv = d.servicetags_from_file(cv) if args.file == True else d.st_array(cv)
             logger.debug("Service Tag -> {}", cv)
             break
 
